"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const EXTENSION_TO_PARSER = {
    ts: 'typescript',
    tsx: 'typescript',
    js: 'babylon',
    jsx: 'babylon',
    'js.flow': 'flow',
    flow: 'flow',
    gql: 'graphql',
    graphql: 'graphql',
    graphqls: 'graphql',
    css: 'postcss',
    scss: 'postcss',
    less: 'postcss',
    stylus: 'postcss',
    markdown: 'markdown',
    md: 'markdown',
    json: 'json'
};
async function prettify(filePath, content) {
    try {
        const prettierPath = require.resolve('prettier');
        if (prettierPath) {
            const prettier = await Promise.resolve().then(() => require('prettier'));
            const fileExtension = path.extname(filePath).slice(1);
            const parser = EXTENSION_TO_PARSER[fileExtension];
            const { ignored } = await prettier.getFileInfo(filePath, { ignorePath: '.prettierignore' });
            if (ignored) {
                return content;
            }
            const config = await prettier.resolveConfig(filePath, { useCache: true, editorconfig: true });
            return prettier.format(content, Object.assign({ parser }, (config || {})));
        }
        return content;
    }
    catch (e) {
        return content;
    }
}
exports.prettify = prettify;
//# sourceMappingURL=prettier.js.map